@@ -108,6 +108,7 @@ class ParquetFile(object):
         self.pandas_nulls = pandas_nulls
         self._base_dtype = dtypes
         self.tz = None
+        self._columns_dtype = None
         if open_with is default_open and fs is None:
             fs = fsspec.filesystem("file")
         elif fs is not None:
@@ -311,11 +312,14 @@ class ParquetFile(object):
         new_rgs = self.row_groups[item]
         if not isinstance(new_rgs, list):
             new_rgs = [new_rgs]
-        new_pf = copy.deepcopy(self)
-        new_pf.fmd.row_groups = new_rgs
-        new_pf._set_attrs()
-        # would otherwise be "simple" when selecting one rg
-        new_pf.file_scheme = self.file_scheme
+        new_pf = object.__new__(ParquetFile)
+        fmd = copy.copy(self.fmd)
+        fmd.row_groups = new_rgs
+        new_pf.__setstate__(
+            {"fn": self.fn, "open": self.open, "fmd": fmd,
+             "pandas_nulls": self.pandas_nulls, "_base_dtype": self._base_dtype,
+             "tz": self.tz}
+        )
         return new_pf
 
     def __len__(self):
@@ -789,7 +793,7 @@ selection does not match number of rows in DataFrame.')
         categories = self.check_categories(categories)
         cats = {k: v for k, v in self.cats.items() if k in columns}
         df, arrs = _pre_allocate(size, columns, categories, index, cats,
-                                 dtypes, self.tz)
+                                 dtypes, self.tz, columns_dtype=self._columns_dtype)
         i_no_name = re.compile(r"__index_level_\d+__")
         if self.has_pandas_metadata:
             md = self.pandas_metadata
@@ -854,12 +858,14 @@ selection does not match number of rows in DataFrame.')
             return cats or {}
         if cats is None:
             return categ or {}
-        if set(cats) - set(categ):
+        if set(cats) - set(categ) and len(self.row_groups) > 1:
             raise TypeError("Attempt to read as category a field that "
                             "was not stored as such")
         if isinstance(cats, dict):
             return cats
-        return {k: v for k, v in categ.items() if k in cats}
+        out = {k: v for k, v in categ.items() if k in cats}
+        out.update({c: pd.RangeIndex(0, 2**14) for c in cats if c not in categ})
+        return out
 
     @property
     def has_pandas_metadata(self):
@@ -884,6 +890,10 @@ selection does not match number of rows in DataFrame.')
             return self._categories
         if self.has_pandas_metadata:
             metadata = self.pandas_metadata
+            if "column_indexes" in metadata and len(metadata["column_indexes"]) > 0:
+                self._columns_dtype = metadata["column_indexes"][0]["numpy_type"]
+            else:
+                self._columns_dtype = None
             cats = {}
             for m in metadata['columns']:
                 if m['pandas_type'] != 'categorical':
@@ -1016,7 +1026,7 @@ selection does not match number of rows in DataFrame.')
     __repr__ = __str__
 
 
-def _pre_allocate(size, columns, categories, index, cs, dt, tz=None):
+def _pre_allocate(size, columns, categories, index, cs, dt, tz=None, columns_dtype=None):
     index = [index] if isinstance(index, str) else (index or [])
     cols = [c for c in columns if c not in index]
     categories = categories or {}
@@ -1037,7 +1047,8 @@ def _pre_allocate(size, columns, categories, index, cs, dt, tz=None):
     cols.extend(cs)
     dtypes.extend(['category'] * len(cs))
     df, views = dataframe.empty(dtypes, size, cols=cols, index_names=index,
-                                index_types=index_types, cats=cats, timezones=tz)
+                                index_types=index_types, cats=cats, timezones=tz,
+                                columns_dtype=columns_dtype)
     return df, views
 
 
@@ -1338,7 +1349,8 @@ def filter_row_groups(pf, filters, as_idx: bool = False):
     # `filters` into a list (OR condition) of list (AND condition)
     # of filters (tuple or list with 1st component being a column
     # name).
-    filters = [[filt] if filt and isinstance(filt[0], str) else filt for filt in filters]
+    if filters[0] and isinstance(filters[0][0], str):
+        filters = [filters]
     # Retrieve all column names onto which are applied filters, and check they
     # are existing columns of the dataset.
     as_cols = pf.columns + list(pf.cats.keys())
